pro be_test4


dir='/home/linux/data/Spectro-Interferometry/data/'
datadir=dir+'/amber/'
inputfile=dir+'param_example.dat'
outputfile=dir+'datacube.fits'


;Loading the amber data from the files in the amber directory
amber_getall_night,datadir,data=data,nobs=nobs,/deg
spectra=readarray(datadir+'/alpha_col_final_spectrum.spec')

;Computing the data-cube
Be_disk_model,inputfile,outputfile=outputfile,outputarray=map,lam=lam,kinemap=kinemap,lineprofile=lineprofile


;Extracting Baseline length and orientation from the data structure and puting them into 1D-arrays
B=[*(data[0].B),*(data[1].B)]
angle=[*(data[0].angle),*(data[1].angle)]

;Simulating observations using the computed datacube and the extracted baselines
simulate_obs,outputfile,B=B,angle=angle,visi=visi,phase=phase,lam=lam


;The xrange here is in micron that why lam is multiply by 1e6 in the calls to plot procedure
xr=[2.16,2.172] 


;7 subwindows per row = 3 for the visibilities + 3 for the differential phases + 1 for the closure phase
!P.multi=[0,8,nobs]  
window,0,xsize=1800,ysize=600


;intiating chi2 and number of point for integration
chi2=0;
npts=0;

;defining the wavelengths that separated the line and the continuum
lam_min=2.164e-6
lam_max=2.167e-6


;Main loops on i=observation and j=baseline
for i=0,nobs-1 do begin

  ;defining the indices of wavelength in the continuum and in the line
  w_cont=where(*(data[i]).lam lt lam_min or  *(data[i]).lam gt lam_max)
  w_line=where(*(data[i]).lam ge lam_min and *(data[i]).lam le lam_max) 
  
  for j=0,2 do begin 
    ;estimating the uncertainty using the continuum  noise
    mom_Vij=moment(sqrt((*(data[i].sqV))[w_cont,j]))
    sigma_Vij=sqrt(mom_Vij[1])
    mom_phij=moment((*(data[i].phi))[w_cont,j])
    sigma_phij=sqrt(mom_phij[1])
  
    ;printing the sigma on the visbility and phase for each baselines
    print,'Obs=',i,' Baseline=',j,' SigmaVij=',sigma_Vij,' SigmaPhij=', sigma_phij
    
    ;interpolation of the model to the observed wavelengths
    visi_interp=interpol(visi[j+i*3,*],lam,(*(data[i]).lam)[w_line])
    phase_interp=interpol(phase[i*3+j,*]*!radeg,lam,(*(data[i]).lam)[w_line])
  
    ;Computing chi2 on the visibility
    chi2vij=total((sqrt((*(data[i].sqV))[w_line,j])-visi_interp)^2./sigma_vij^2.)
    npts=npts+n_elements(visi_interp)
    print,'chi2r_Vij=',chi2vij/n_elements(visi_interp)
    
    ;Computing chi2 on the phase
    chi2phij=total((phase_interp-(*(data[i].phi))[w_line,j])^2./sigma_phij^2.)
    npts=npts+n_elements(phase_interp)
    print,'chi2r_phij=',chi2phij/n_elements(phase_interp)
    
   
    ;Incrementing the chi2
    chi2=chi2+chi2vij+chi2phij
  
    ;Plotting the observations and the interpolated-model 
    plot,*(data[i]).lam*1e6,sqrt((*(data[i].sqV))[*,j]),xrange=xr,yrange=[0,1.2] 
    oplot, (*(data[i]).lam)[w_line]*1e6,visi_interp,color=230
    xyouts,2.166,0.1,"B!D"+strtrim(string(3*i+j+1),2)+"!N="+strtrim(string((*(data[i].B))[j],format='(F5.1)'),2)+"m    P.A.="+strtrim(string((*(data[i].angle))[j],format='(F6.1)'),2)+"!Uo!N",alignment=0.5
    plot,(*(data[i]).lam)*1e6,(*(data[i].phi))[*,j],xrange=xr,yrange=[-50,50]
    oplot, (*(data[i]).lam)[w_line]*1e6,phase_interp,color=230  
    
  end
  plot,*(data[i]).lam*1e6,(*(data[i].cphi)),xrange=xr,yrange=[-50,50]
  oplot,lam*1e6,(phase[3*i+0,*]+phase[3*i+1,*]-phase[3*i+2,*])*!radeg,color=230 
  
 plot,spectra[0,*]*1e6,spectra[1,*],xrange=xr
 oplot,lam*1e6,lineprofile,color=230 
     
end
chi2r=chi2/(npts-11)
print,"Final chi2r=",chi2r
!P.multi=0

end